==> mingw-w64-clang-aarch64-glfw-3.3.9-1-any.pkg.tar.zst: clangarm64/share/doc/glfw/html/search/all_13.js <==
var searchData=
[
  ['package_20support_0',['CMake config-file package support',['../news.html#news_32_cmake',1,'']]],
  ['parameter_20to_20clipboard_20functions_1',['Window parameter to clipboard functions',['../news.html#clipboard_window_33',1,'']]],
  ['parameters_2',['Window handle parameters',['../moving_guide.html#moving_window_handles',1,'']]],
  ['path_20drop_20event_3',['Path drop event',['../news.html#news_31_drop',1,'']]],
  ['path_20drop_20input_4',['Path drop input',['../input_guide.html#path_drop',1,'']]],
  ['per_20window_20user_20pointer_5',['Per-window user pointer',['../news.html#news_30_wndptr',1,'']]],
  ['persistent_20window_20hints_6',['Persistent window hints',['../moving_guide.html#moving_hints',1,'']]],
  ['physical_20key_20input_7',['Physical key input',['../moving_guide.html#moving_keys',1,'']]],
  ['physical_20size_8',['Physical size',['../monitor_guide.html#monitor_size',1,'']]],
  ['pixels_9',['pixels',['../struct_g_l_f_wimage.html#a0c532a5c2bb715555279b7817daba0fb',1,'GLFWimage']]],
  ['pkg_20config_20on_20unix_10',['With makefiles and pkg-config on Unix',['../build_guide.html#build_link_pkgconfig',1,'']]],
  ['platform_20interface_11',['Platform interface',['../internals_guide.html#internals_platform',1,'']]],
  ['platform_20specific_20scancodes_12',['Platform-specific scancodes',['../news.html#news_30_scancode',1,'']]],
  ['pointer_13',['pointer',['../input_guide.html#joystick_userptr',1,'Joystick user pointer'],['../news.html#news_30_wndptr',1,'Per-window user pointer'],['../monitor_guide.html#monitor_userptr',1,'User pointer'],['../window_guide.html#window_userptr',1,'User pointer']]],
  ['pointer_20lifetimes_14',['Pointer lifetimes',['../intro_guide.html#lifetime',1,'']]],
  ['pointers_15',['pointers',['../context_guide.html#context_glext_proc',1,'Fetching function pointers'],['../news.html#device_userptr_33',1,'Monitor and joystick user pointers'],['../vulkan_guide.html#vulkan_proc',1,'Querying Vulkan function pointers']]],
  ['polling_16',['Removal of automatic event polling',['../moving_guide.html#moving_autopoll',1,'']]],
  ['position_17',['position',['../input_guide.html#cursor_pos',1,'Cursor position'],['../news.html#news_31_direct',1,'Direct access for window attributes and cursor position'],['../monitor_guide.html#monitor_pos',1,'Virtual position'],['../window_guide.html#window_pos',1,'Window position']]],
  ['position_20callback_18',['Window position callback',['../news.html#news_30_wndposfun',1,'']]],
  ['position_20changes_19',['Cursor position changes',['../moving_guide.html#moving_cursorpos',1,'']]],
  ['position_20query_20',['Window position query',['../news.html#news_30_wndpos',1,'']]],
  ['position_20replaced_20by_20scroll_20offsets_21',['Wheel position replaced by scroll offsets',['../moving_guide.html#moving_wheel',1,'']]],
  ['presentation_20support_22',['Querying for Vulkan presentation support',['../vulkan_guide.html#vulkan_present',1,'']]],
  ['processing_23',['processing',['../input_guide.html#events',1,'Event processing'],['../window_guide.html#window_events',1,'Window event processing']]],
  ['processing_20events_24',['Processing events',['../quick_guide.html#quick_process_events',1,'']]],
  ['properties_25',['Monitor properties',['../monitor_guide.html#monitor_properties',1,'']]],
  ['properties_20and_20events_26',['Window properties and events',['../window_guide.html#window_properties',1,'']]],
  ['protocol_27',['Support for the wl_shell protocol',['../news.html#wl_shell_33',1,'']]],
  ['protocols_20and_20ipc_20standards_28',['protocols and ipc standards',['../compat_guide.html#compat_wayland',1,'Wayland protocols and IPC standards'],['../compat_guide.html#compat_x11',1,'X11 extensions, protocols and IPC standards']]],
  ['public_20interface_29',['Public interface',['../internals_guide.html#internals_public',1,'']]],
  ['putting_20it_20together_30',['Putting it together',['../quick_guide.html#quick_example',1,'']]]
];

==> mingw-w64-clang-aarch64-glfw-3.3.9-2-any.pkg.tar.zst: clangarm64/share/doc/glfw/html/search/all_13.js <==
var searchData=
[
  ['package_20support_0',['CMake config-file package support',['../news.html#news_32_cmake',1,'']]],
  ['parameter_20to_20clipboard_20functions_1',['Window parameter to clipboard functions',['../news.html#clipboard_window_33',1,'']]],
  ['parameters_2',['Window handle parameters',['../moving_guide.html#moving_window_handles',1,'']]],
  ['path_20drop_20event_3',['Path drop event',['../news.html#news_31_drop',1,'']]],
  ['path_20drop_20input_4',['Path drop input',['../input_guide.html#path_drop',1,'']]],
  ['per_20window_20user_20pointer_5',['Per-window user pointer',['../news.html#news_30_wndptr',1,'']]],
  ['persistent_20window_20hints_6',['Persistent window hints',['../moving_guide.html#moving_hints',1,'']]],
  ['physical_20key_20input_7',['Physical key input',['../moving_guide.html#moving_keys',1,'']]],
  ['physical_20size_8',['Physical size',['../monitor_guide.html#monitor_size',1,'']]],
  ['pixels_9',['pixels',['../struct_g_l_f_wimage.html#a0c532a5c2bb715555279b7817daba0fb',1,'GLFWimage']]],
  ['pkg_20config_20on_20unix_10',['With makefiles and pkg-config on Unix',['../build_guide.html#build_link_pkgconfig',1,'']]],
  ['platform_20interface_11',['Platform interface',['../internals_guide.html#internals_platform',1,'']]],
  ['platform_20specific_20scancodes_12',['Platform-specific scancodes',['../news.html#news_30_scancode',1,'']]],
  ['pointer_13',['Pointer',['../input_guide.html#joystick_userptr',1,'Joystick user pointer'],['../news.html#news_30_wndptr',1,'Per-window user pointer'],['../monitor_guide.html#monitor_userptr',1,'User pointer'],['../window_guide.html#window_userptr',1,'User pointer']]],
  ['pointer_20lifetimes_14',['Pointer lifetimes',['../intro_guide.html#lifetime',1,'']]],
  ['pointers_15',['Pointers',['../context_guide.html#context_glext_proc',1,'Fetching function pointers'],['../news.html#device_userptr_33',1,'Monitor and joystick user pointers'],['../vulkan_guide.html#vulkan_proc',1,'Querying Vulkan function pointers']]],
  ['polling_16',['Removal of automatic event polling',['../moving_guide.html#moving_autopoll',1,'']]],
  ['position_17',['Position',['../input_guide.html#cursor_pos',1,'Cursor position'],['../news.html#news_31_direct',1,'Direct access for window attributes and cursor position'],['../monitor_guide.html#monitor_pos',1,'Virtual position'],['../window_guide.html#window_pos',1,'Window position']]],
  ['position_20callback_18',['Window position callback',['../news.html#news_30_wndposfun',1,'']]],
  ['position_20changes_19',['Cursor position changes',['../moving_guide.html#moving_cursorpos',1,'']]],
  ['position_20query_20',['Window position query',['../news.html#news_30_wndpos',1,'']]],
  ['position_20replaced_20by_20scroll_20offsets_21',['Wheel position replaced by scroll offsets',['../moving_guide.html#moving_wheel',1,'']]],
  ['presentation_20support_22',['Querying for Vulkan presentation support',['../vulkan_guide.html#vulkan_present',1,'']]],
  ['processing_23',['Processing',['../input_guide.html#events',1,'Event processing'],['../window_guide.html#window_events',1,'Window event processing']]],
  ['processing_20events_24',['Processing events',['../quick_guide.html#quick_process_events',1,'']]],
  ['properties_25',['Monitor properties',['../monitor_guide.html#monitor_properties',1,'']]],
  ['properties_20and_20events_26',['Window properties and events',['../window_guide.html#window_properties',1,'']]],
  ['protocol_27',['Support for the wl_shell protocol',['../news.html#wl_shell_33',1,'']]],
  ['protocols_20and_20ipc_20standards_28',['Protocols and IPC standards',['../compat_guide.html#compat_wayland',1,'Wayland protocols and IPC standards'],['../compat_guide.html#compat_x11',1,'X11 extensions, protocols and IPC standards']]],
  ['public_20interface_29',['Public interface',['../internals_guide.html#internals_public',1,'']]],
  ['putting_20it_20together_30',['Putting it together',['../quick_guide.html#quick_example',1,'']]]
];
